==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetGatewayRouteSpecHttp2RouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property hostnames
 * @property paths
 * @property prefixes
 */
public data class GetGatewayRouteSpecHttp2RouteActionRewrite(
    public val hostnames: List<GetGatewayRouteSpecHttp2RouteActionRewriteHostname>,
    public val paths: List<GetGatewayRouteSpecHttp2RouteActionRewritePath>,
    public val prefixes: List<GetGatewayRouteSpecHttp2RouteActionRewritePrefix>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetGatewayRouteSpecHttp2RouteActionRewrite):
            GetGatewayRouteSpecHttp2RouteActionRewrite = GetGatewayRouteSpecHttp2RouteActionRewrite(
            hostnames = javaType.hostnames().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttp2RouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }),
            paths = javaType.paths().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttp2RouteActionRewritePath.Companion.toKotlin(args0)
                })
            }),
            prefixes = javaType.prefixes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttp2RouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetGatewayRouteSpecHttp2RouteActionRewrite.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property hostnames
 * @property paths
 * @property prefixes
 */
public data class GetGatewayRouteSpecHttp2RouteActionRewrite(
    public val hostnames: List<GetGatewayRouteSpecHttp2RouteActionRewriteHostname>,
    public val paths: List<GetGatewayRouteSpecHttp2RouteActionRewritePath>,
    public val prefixes: List<GetGatewayRouteSpecHttp2RouteActionRewritePrefix>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetGatewayRouteSpecHttp2RouteActionRewrite): GetGatewayRouteSpecHttp2RouteActionRewrite = GetGatewayRouteSpecHttp2RouteActionRewrite(
            hostnames = javaType.hostnames().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttp2RouteActionRewriteHostname.Companion.toKotlin(args0)
                })
            }),
            paths = javaType.paths().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttp2RouteActionRewritePath.Companion.toKotlin(args0)
                })
            }),
            prefixes = javaType.prefixes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetGatewayRouteSpecHttp2RouteActionRewritePrefix.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
